###########################################################################
#
# NPDateList.pm -- classifier plugin for sorting by date
# A component of the Greenstone digital library software
# from the New Zealand Digital Library Project at the 
# University of Waikato, New Zealand.
#
# Copyright (C) 1999 New Zealand Digital Library Project
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
###########################################################################

# overridden for niupepa as we don't want to include abstracts directly in lists

package NPDateList;

use DateList;

sub BEGIN {
    @ISA = ('DateList');
}

sub classify {
    my $self = shift (@_);
    my ($doc_obj) = @_;

    # want to ignore abstracts
    my $doctype = $doc_obj->get_metadata_element($doc_obj->get_top_section(), 'doctype');
    return if (defined $doctype && $doctype eq 'Description');

    my $doc_OID = $doc_obj->get_OID();
    my $date = $doc_obj->get_metadata_element ($doc_obj->get_top_section(), 'Date');

    # if this document doesn't contain Date element we won't 
    # include it in this classification
    if (defined $date && $date =~ /\d/) {
	if (defined $self->{'list'}->{$doc_OID}) {
	    print STDERR "WARNING: DateList::classify called multiple times for $doc_OID\n";
	} 
	$self->{'list'}->{$doc_OID} = $date;
    }
}

1;
